@@ -1,8 +1,8 @@
-__version__ = '0.2.7'
+__version__ = '0.3.0'
 
 from pypads_padre.app.plugin import configure_plugin
 
 
 # Entrypoint for the plugin TODO allow to disable this we could also call a defined entrypoint from pypads and decide
-def activate():
-    configure_plugin()
+def activate(pypads):
+    configure_plugin(pypads)
