@@ -1,7 +1,7 @@
 from pypads.bindings.anchors import Anchor, anchors
 
-DEFAULT_ANCHORS = [Anchor("pypads_dataset", "TODO"),
-                   Anchor("pypads_split", "TODO"),
+DEFAULT_ANCHORS = [Anchor("pypads_dataset", "Used if a dataset is being detected"),
+                   Anchor("pypads_split", "Used when splitting the dataset"),
                    Anchor("pypads_params", "TODO"),
                    Anchor("pypads_param_search", "TODO"),
                    Anchor("pypads_param_search_exec", "TODO"),
